/* eslint-disable no-undef */
const createGetContextImpl = require('..');

describe('get-context-impl', () => {
    it('Should get a secret-store context', async () => {
        const apiHost = 'http://codefresh.io';
        const apiKey = '1234abcd';

        const getContext = createGetContextImpl({ apiHost, apiKey });

        fetch.mockResponse(async (req) => {
            expect(req.url).toBe(`http://codefresh.io/api/contexts/secret1/prepare`);
            expect(req.method).toBe('GET');
            expect(req.headers.get('Authorization')).toBe(apiKey);

            return {
                status: 200,
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    'apiVersion': 'v1',
                    'kind': 'context',
                    'owner': 'account',
                    'metadata': {
                        'name': 'secret1'
                    },
                    'spec': {
                        'type': 'secret-store.hashicorp-vault',
                        'data': {
                            'apiUrl': 'http://localhost:8200',
                            'auth': {
                                'type': 'token',
                                'token': 'foo'
                            }
                        }
                    }
                }),
            };
        });

        const ctx = await getContext('secret-store', { context: { name: 'secret1' } });
        expect(ctx.metadata.name).toBe('secret1');
    });

    it('Should get a cluster context', async () => {
        const apiHost = 'http://codefresh.io';
        const apiKey = '1234abcd';

        const getContext = createGetContextImpl({ apiHost, apiKey });

        fetch.mockResponse(async (req) => {
            expect(req.url).toBe(`http://codefresh.io/api/clusters/cluster-1/credentials`);
            expect(req.method).toBe('GET');
            expect(req.headers.get('Authorization')).toBe(apiKey);

            return {
                status: 200,
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    'url': 'https://kubernetes:1234',
                    'auth': {
                        'bearer': 'foo='
                    },
                    'ca': 'bar==',
                    'type': 'sat'
                }),
            };
        });

        const ctx = await getContext('kubernetes-cluster', { selector: 'cluster-1' });
        expect(ctx.url).toBe('https://kubernetes:1234');
    });
});
