/**
 * resolveKey options
 */
export type ResolveKeyOptions = {
    /**
     * - resolvers
     */
    resolvers: {
        [x: string]: Resolver;
    };
    /**
     * - key
     */
    key: string;
    /**
     * - index
     */
    index: number;
    /**
     * - timeout for single variable resolution
     */
    timeout: number | null;
    /**
     * - logger
     */
    log: Logger;
    /**
     * - a function used by the variable resolver to retrieve contexts
     */
    getContext: (arg0: string, arg1: any, arg2: Logger) => Promise<any>;
    /**
     * - a function used by the variable resolver to add a new mask
     */
    addNewMask: (arg0: Resolution, arg1: Logger) => Promise<void> | undefined;
};
/**
 * Logger
 */
export type Logger = {
    /**
     * - log info level
     */
    info: (arg0: string) => undefined;
    /**
     * - log warn level
     */
    warn: (arg0: string) => undefined;
};
/**
 * getContextFn
 */
export type getContextFn = (arg0: string, arg1: any, arg2: Logger) => Promise<any>;
/**
 * Resolver
 */
export type Resolver = {
    /**
     * - resolution function, gets: variable, getContextFn, and logger
     */
    resolve: (arg0: string, arg1: getContextFn, arg2: Logger) => Promise<string>;
};
/**
 * Resolution
 */
export type Resolution = {
    /**
     * - index
     */
    index: number;
    /**
     * - key
     */
    key: string;
    /**
     * - resolved
     */
    resolved: boolean;
    /**
     * - value
     */
    value: string;
};
/**
 * PathResolution
 */
export type PathResolution = {
    /**
     * - path
     */
    path: string;
    /**
     * - resolution
     */
    resolution: Resolution;
};
/**
 * Variable resolver options
 */
export type Options = {
    /**
     * - sets the timeout for single variable resolution
     */
    singleResolutionTimeout: number | undefined;
    /**
     * - sets the timeout for the entire resolution
     */
    completeResolutionFlowTimeout: number | undefined;
    /**
     * - sets the timeout for the entire resolution
     */
    log: Logger | undefined;
    /**
     * - a function used by the variable resolver to retrieve contexts
     */
    getContext: undefined | ((arg0: string, arg1: any, arg2: Logger) => Promise<any>);
    /**
     * - a function used by the variable resolver to add a new mask
     */
    addNewMask: undefined | ((arg0: Resolution, arg1: Logger) => Promise<void>);
};
/**
 * resolution options
 */
export type ResolutionOptions = {
    /**
     * - sets the timeout for single variable resolution
     */
    timeout: number | undefined;
    /**
     * - sets the timeout for the entire resolution
     */
    log: Logger | undefined;
    /**
     * - a function used by the variable resolver to retrieve contexts
     */
    getContext: (arg0: string, arg1: any, arg2: Logger) => Promise<any>;
    /**
     * - a function used by the variable resolver to add a new mask
     */
    addNewMask: (arg0: Resolution, arg1: Logger) => Promise<void>;
};
/**
 * VariableResolver
 */
export type VariableResolver = {
    /**
     * - resolve a string variable
     */
    resolve: (arg0: string, arg1: ResolutionOptions) => Promise<Resolution[]>;
    /**
     * - recursively resolve secrets on an object
     */
    recursive: (arg0: any, arg1: ResolutionOptions) => Promise<PathResolution[]>;
    /**
     * - recursively resolves secrets on a context according to secretStoreReferences field
     */
    resolveSecretReferences: (arg0: any, arg1: ResolutionOptions) => Promise<any>;
    /**
     * - sets the getContext function of the variable resolver
     */
    setGetContext: (arg0: getContextFn) => any;
    /**
     * - sets the addNewMask function of the variable resolver
     */
    setAddNewMask: (arg0: (arg0: Resolution, arg1: Logger) => Promise<void>) => any;
};
/**
 * Builds a new variable resolver
 * @param {Object.<string, Resolver>} resolvers resolvers
 * @param {Options} options options
 * @returns {VariableResolver} variableResolver
 */
export function build(resolvers: {
    [x: string]: Resolver;
}, options: Options): VariableResolver;
